@@ -4,9 +4,9 @@
     'name': 'Company',
     'name_de_DE': 'Unternehmen',
     'name_es_CO': 'Compañía',
-    'name_es_ES': 'Compañía',
-    'name_fr_FR': 'Compagnie',
-    'version': '1.2.4',
+    'name_es_ES': 'Empresa',
+    'name_fr_FR': 'Société',
+    'version': '1.4.3',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -31,19 +31,19 @@ Make the scheduler run on each companies.
  - Añade plantilla de carta a un tercero.
  - Se ejecuta el agendador por compañía.
 ''',
-    'description_es_ES': ''' - Define compañía y empleados.
- - Añade compañía principal y predeterminada de acuerdo a preferencia de usuarios.
- - Añade compañía a las propiedades.
- - Define un nuevo reporteador para los encabezados de los reportes por compañía.
- - Añade plantilla de carta a un tercero.
- - Se ejecuta el agendador por compañía.
+    'description_es_ES': '''Define empresa y empleados.
+ - Añade la empresa principal y predeterminada en las preferencias de los usuarios.
+ - Añade empresa a las propiedades.
+ - Define un nuevo analizador de informe para los informes con el encabezado de la empresa.
+ - Añade una plantilla de carta en terceros.
+ - Hace que el programador de tareas se ejecute por empresa.
 ''',
-    'description_fr_FR': '''Defini compagnie et employé.
-Ajoute les compagnies principale et courante dans les préférences de l'utilisateur.
-Ajoute la compagnie sur les propriétés.
-Défini un nouveau moteur de rapport gérant une entête par compagnie.
+    'description_fr_FR': '''Défini société et employé.
+Ajoute les sociétés principale et courante dans les préférences de l'utilisateur.
+Ajoute la société sur les propriétés.
+Défini un nouveau moteur de rapport gérant une entête par société.
 Ajoute un canva de lettre par tiers.
-Lance les planificateurs sur chaque compagnie.
+Lance les planificateurs sur chaque société.
 ''',
     'depends': [
         'ir',
@@ -56,9 +56,9 @@ Lance les planificateurs sur chaque compagnie.
         'cron.xml',
     ],
     'translation': [
-        'fr_FR.csv',
+        'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
-        'de_DE.csv',
+        'fr_FR.csv',
     ]
 }
